function [xyCont, abCont, mxyCont, xvyvCont] = contraction(part, meas, contIterations, partPr, P)

N = size(part.x,1);
M = size(meas,1);

% Contraction of velocity for correlated velocity motion model
t = P.dt_s;
Tx = P.Tx;
Ty = P.Ty;
Fx = exp(-t/Tx);
Fy = exp(-t/Ty);
tContrX = ((1 - Fx)*Tx);
tContrY = ((1 - Fy)*Ty);
tContr = [repmat(tContrX, [N,M]); repmat(tContrY, [N,M])];

% Construct the matrices for the contraction
xyCont = repmat([part.x(:,part.indX); part.x(:,part.indY)],[1,M]);
abCont = repmat([part.x(:,part.indA); part.x(:,part.indB)],[1,M]);

mxyCont = [repmat(meas(:,1),1,N)'; repmat(meas(:,2),1,N)'];
if ~isempty(partPr)
    xvyvCont = repmat([part.x(:,part.indX+1); part.x(:,part.indY+1)],[1,M]);
    xyContPr = repmat([partPr.x(:,partPr.indX); partPr.x(:,partPr.indY)],[1,M]);
end
V = infsup(0,1);

% Contract
for it = 1:contIterations
    temp(:,:,1) =  intersect(xyCont, mxyCont + abCont/2.*V);
    temp(:,:,2) =  intersect(xyCont, mxyCont - abCont/2.*V);
    xyCont = hullVect(temp,3);
    
    temp(:,:,1) =  intersect(abCont, divideInt(2*(mxyCont - xyCont),V));
    temp(:,:,2) =  intersect(abCont, divideInt(-1*2*(mxyCont - xyCont),V));
    abCont = hullVect(temp,3);
    
    temp(:,:,1) =  intersect(mxyCont, xyCont + abCont/2.*V);
    temp(:,:,2) =  intersect(mxyCont, xyCont - abCont/2.*V);
    mxyCont = hullVect(temp,3);
    if ~isempty(partPr)
        xvyvCont = intersect(xvyvCont, divideInt((xyCont - xyContPr), intval(tContr)));
    else
        xvyvCont = [];
    end
end
end