%% Box Particle Filter for crowd tracking
%% Code written by: Allan De Freitas (a.defreitas@sheffield.ac.uk)
%% Requires Intlab Toolbox (http://www.ti3.tu-harburg.de/rump/intlab/) 
%% for interval operations

clear;close all hidden;clc;
systemInitialise % Intlab,visualisation, and parameter initialisation
[state,meas,figParam,Param] = crowdInitialise(Param);  % crowd initialisation (states and measurements)
[particles] = boxPF_Initialise(state(1,:)); % Box particle filter initialisation
for k = 1:Param.timeSteps
    if k > 1
        %% Prediction
        particlesPred = evolutionModelCorrVel(particles,Param);
    end
    %% Update
    if k == 1
        [perf,particlesUpdate,Param] = update(particles,meas{k}, [],perf,k,Param,state,[]);
    else
        [perf,particlesUpdate,Param] = update(particlesPred,meas{k}, particles,perf,k,Param,state,estimate(k-1,[5,6]));
    end
    %% Estimate
    estimate(k,:) = particlesUpdate.weights'*particlesUpdate.x;
    %% Resampling
    [particles,list] = resampling(particlesUpdate);
    %% Visualisation
    visualise;
    fprintf('timestep = %i / %i.\r',k,Param.timeSteps);
end                                                                                                 
set(0, 'DefaultFigureVisible', 'on')
if Param.saveMovie
    close(writerObj);
end
