% *************************************************************************
function z_fa = uniformPoints(gammaThreshold, S, z_hat, m_FA)
% *************************************************************************
%                         Code taken from:                                *                                  
%             An Efficient Method for Generating Points                   *
%             Uniformly Distributed in Hyperellipsoids                    *
%                  Jean Dezert and Christian Musso                        *
% *************************************************************************
% This routine implements the new algorithm for generating random
% points uniformly distributed in hyperellipsoid for nz>=2.
% Inputs: gammaThreshold = Gating Threshold (>0)
% S = Covariance matrix S (dim(S)=nzxnz)
% z_hat = center of the gate ( dim(z_hat)=nzx1)
% m_FA = number of false alarms to generate in the gate
% Output: Z_fa = [ z(1),... z(mFA)] set of FA generated by new algorithm
% *************************************************************************
nz = length(S);
X_Cnz = randn(nz,m_FA);
X_Cnz = X_Cnz./kron(ones(nz,1),sqrt(sum(X_Cnz.^2)));            % Points uniformly distributed on hypersphere
R = ones(nz,1)*(rand(1,m_FA).^(1/nz));                          % Points with pdf nz(nz?1); 0<r<1
unif_sph = R.*X_Cnz;                                            % m FA points in the hypersphere
T = chol(S);                                                    % Cholesky factorization of S => S=T'T
unif_ell = T'*unif_sph ;                                        % Hypersphere to hyperellipsoid mapping
z_fa =( unif_ell*sqrt(gammaThreshold) + (z_hat*ones(1,m_FA)));  % Translation around gate center